/*
 *  Version: 1.0
 *
 *  The contents of this file are subject to the OpenVPMS License Version
 *  1.0 (the 'License'); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *  http://www.openvpms.org/license/
 *
 *  Software distributed under the License is distributed on an 'AS IS' basis,
 *  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 *  for the specific language governing rights and limitations under the
 *  License.
 *
 *  Copyright 2008 (C) OpenVPMS Ltd. All Rights Reserved.
 *
 *  $Id$
 */

package org.openvpms.component.business.dao.hibernate.im.archetype;

import org.openvpms.component.business.domain.im.archetype.descriptor.AssertionTypeDescriptor;

import java.util.Set;


/**
 * Data object interface corresponding to the {@link AssertionTypeDescriptor}
 * class.
 *
 * @author <a href="mailto:support@openvpms.org">OpenVPMS Team</a>
 * @version $LastChangedDate: 2006-05-02 05:16:31Z $
 */
public interface AssertionTypeDescriptorDO extends DescriptorDO {

    /**
     * Returns the action types.
     *
     * @return the action types
     */
    Set<ActionTypeDescriptorDO> getActionTypes();

    /**
     * Add an action type.
     *
     * @param type the action type to add
     */
    void addActionType(ActionTypeDescriptorDO type);

    /**
     * Retrieves the named action type.
     *
     * @param name the action name
     * @return the corresponding action type, or <tt>null</tt> if none is found
     */
    ActionTypeDescriptorDO getActionType(String name);

    /**
     * Removes the specified action type.
     *
     * @param type the action type to remove
     */
    void removeActionType(ActionTypeDescriptorDO type);

    /**
     * Returns the property archetype.
     *
     * @return the property archetype
     */
    String getPropertyArchetype();

    /**
     * Returns the property archetype.
     *
     * @param propertyArchetype the property archetype
     */
    void setPropertyArchetype(String propertyArchetype);
}
