/*
 *  Version: 1.0
 *
 *  The contents of this file are subject to the OpenVPMS License Version
 *  1.0 (the 'License'); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *  http://www.openvpms.org/license/
 *
 *  Software distributed under the License is distributed on an 'AS IS' basis,
 *  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 *  for the specific language governing rights and limitations under the
 *  License.
 *
 *  Copyright 2006 (C) OpenVPMS Ltd. All Rights Reserved.
 *
 *  $Id: InformationWorkspace.java 4632 2012-03-07 04:27:43Z tanderson $
 */

package org.openvpms.web.app.customer.info;

import nextapp.echo2.app.Component;
import org.openvpms.component.business.domain.im.party.Party;
import org.openvpms.web.app.customer.CustomerSummary;
import org.openvpms.web.app.customer.CustomerBrowser;
import org.openvpms.web.app.subsystem.BasicCRUDWorkspace;
import org.openvpms.web.component.subsystem.CRUDWindow;
import org.openvpms.web.component.app.ContextHelper;
import org.openvpms.web.component.app.GlobalContext;
import org.openvpms.web.component.im.query.BrowserDialog;


/**
 * Customer information workspace.
 *
 * @author <a href="mailto:support@openvpms.org">OpenVPMS Team</a>
 * @version $LastChangedDate: 2012-03-07 15:27:43 +1100 (Wed, 07 Mar 2012) $
 */
public class InformationWorkspace extends BasicCRUDWorkspace<Party> {

    /**
     * Construct a new <tt>InformationWorkspace</tt>.
     */
    public InformationWorkspace() {
        super("customer", "info");
        setArchetypes(Party.class, "party.customer*");
    }

    /**
     * Sets the current object.
     *
     * @param object the object. May be <tt>null</tt>
     */
    @Override
    public void setObject(Party object) {
        super.setObject(object);
        ContextHelper.setCustomer(object);
        firePropertyChange(SUMMARY_PROPERTY, null, null);
    }

    /**
     * Renders the workspace summary.
     *
     * @return the component representing the workspace summary, or
     *         <code>null</code> if there is no summary
     */
    @Override
    public Component getSummary() {
        CustomerSummary summarizer = new CustomerSummary(GlobalContext.getInstance());
        return summarizer.getSummary(getObject());
    }

    /**
     * Returns the latest version of the current customer context object.
     *
     * @return the latest version of the context object, or {@link #getObject()}
     *         if they are the same
     */
    @Override
    protected Party getLatest() {
        return getLatest(GlobalContext.getInstance().getCustomer());
    }

    /**
     * Lays out the component.
     *
     * @param container the container
     */
    @Override
    protected void doLayout(Component container) {
        super.doLayout(container);
        Party latest = getLatest();
        if (latest != getObject()) {
            setObject(latest);
        }
    }

    /**
     * Creates a new CRUD window.
     *
     * @return a new CRUD window
     */
    @Override
    protected CRUDWindow<Party> createCRUDWindow() {
        return new InformationCRUDWindow(getArchetypes());
    }

       /**
     * Invoked when the selection browser is closed.
     *
     * @param dialog the browser dialog
     */
    @Override
    protected void onSelectClosed(BrowserDialog<Party> dialog) {
        if (dialog.createNew()) {
            getCRUDWindow().create();
        } else {
            Party customer = dialog.getSelected();
            if (customer != null) {
                onSelected(customer);
                if (dialog.getBrowser() instanceof CustomerBrowser) {
                    CustomerBrowser browser = (CustomerBrowser) dialog.getBrowser();
                    Party patient = browser.getPatient();
                    if (patient != null) {
                        ContextHelper.setPatient(patient);
                    }
                }
            }
        }
    }

}
